Learn R Programming

epocakir (version 1.0.0)

aki_SCr: AKI Staging based on Changes in Serum Creatinine

Description

Using KDIGO Clinical Practice Guideline for Acute Kidney Injury Volume 2 | Issue 1 | March 2012

Usage

aki_SCr(...)

# S3 method for data.frame aki_SCr(.data, SCr, dttm, pt_id, ...)

# S3 method for units aki_SCr(SCr, dttm, pt_id, ...)

# S3 method for numeric aki_SCr(SCr, dttm, pt_id, ...)

Value

(ordered factor) AKI stages

Arguments

...

Further optional arguments

.data

(data.frame) A data.frame, optional

SCr

Serum creatinine column name, or vector of units or numeric if .data is not provided

dttm

DateTime column name, or vector of POSIXct if .data is not provided

pt_id

Patient ID column name, or vector of characters or factors if .data is not provided

Details

  • AKI Stage 1: \(\ge\)0.3 mg/dl (\(\ge\)26.5 mmol/l) increase

  • AKI Stage 2: N/A

  • AKI Stage 3: \(\ge\)4.0 mg/dl (\(\ge\)353.6 mmol/l)

See https://kdigo.org/guidelines/acute-kidney-injury/ for more details.

Examples

Run this code
aki_SCr(aki_pt_data, SCr = "SCr_", dttm = "dttm_", pt_id = "pt_id_")

aki_pt_data %>%
  dplyr::mutate(aki = aki_SCr(SCr = SCr_, dttm = dttm_, pt_id = pt_id_))

Run the code above in your browser using DataLab