Learn R Programming

epocakir (version 1.0.0)

aki_UO: AKI Staging based on Urine Output

Description

Using KDIGO Clinical Practice Guideline for Acute Kidney Injury Volume 2 | Issue 1 | March 2012

Usage

aki_UO(...)

# S3 method for data.frame aki_UO(.data, UO, dttm, pt_id, ...)

# S3 method for units aki_UO(UO, dttm, pt_id, ...)

# S3 method for numeric aki_UO(UO, dttm, pt_id, ...)

Value

(ordered factor) AKI stages

Arguments

...

Further optional arguments

.data

(data.frame) A data.frame, optional

UO

Urine output column name, or vector of units or numeric if .data is not provided

dttm

DateTime column name, or vector of POSIXct if .data is not provided

pt_id

Patient ID column name, or vector of characters or factors if .data is not provided

Details

  • AKI Stage 1: <0.5 ml/kg/h for 6-12 hours

  • AKI Stage 2: <0.5 ml/kg/h for \(\ge\)12 hours

  • AKI Stage 3: <0.3 ml/kg/h for \(\ge\)24 hours OR Anuria for \(\ge\)12 hours

See https://kdigo.org/guidelines/acute-kidney-injury/ for more details.

Examples

Run this code
aki_UO(aki_pt_data, UO = "UO_", dttm = "dttm_", pt_id = "pt_id_")

aki_pt_data %>%
  dplyr::mutate(aki = aki_UO(UO = UO_, dttm = dttm_, pt_id = pt_id_))

Run the code above in your browser using DataLab