Learn R Programming

epocakir (version 1.0.0)

eGFR_child_SCr: eGFR Pediatric SCr and Height

Description

Using KDIGO 2012 Clinical Practice Guideline for the Evaluation and Management of Chronic Kidney Disease Volume 3 | Issue 1 | January 2013

Usage

eGFR_child_SCr(...)

# S3 method for data.frame eGFR_child_SCr(.data, SCr, height, ...)

# S3 method for units eGFR_child_SCr(SCr, height, ...)

# S3 method for numeric eGFR_child_SCr(SCr, height, ...)

Value

Estimated GFR of the same type provided (numeric or units)

Arguments

...

Further optional arguments

.data

(data.frame) A data.frame, optional

SCr

Serum creatinine column name, or vector of units or numeric if .data is not provided

height

Height of patient column name, or vector of units or numeric if .data is not provided

Details

See https://kdigo.org/guidelines/ckd-evaluation-and-management/ for more details

Examples

Run this code
eGFR_child_SCr(eGFR_pt_data,
  SCr = "SCr_", height = "height_"
)

eGFR_pt_data %>%
  dplyr::mutate(eGFR = eGFR_child_SCr(
    SCr = SCr_, height = height_,
  ))

Run the code above in your browser using DataLab