powered by
Using KDIGO Clinical Practice Guideline for Acute Kidney Injury Volume 2 | Issue 1 | March 2012
aki_SCr(...)# S3 method for data.frame aki_SCr(.data, SCr, dttm, pt_id, ...)# S3 method for units aki_SCr(SCr, dttm, pt_id, ...)# S3 method for numeric aki_SCr(SCr, dttm, pt_id, ...)
# S3 method for data.frame aki_SCr(.data, SCr, dttm, pt_id, ...)
# S3 method for units aki_SCr(SCr, dttm, pt_id, ...)
# S3 method for numeric aki_SCr(SCr, dttm, pt_id, ...)
(ordered factor) AKI stages
Further optional arguments
(data.frame) A data.frame, optional
Serum creatinine column name, or vector of units or numeric if .data is not provided
.data
DateTime column name, or vector of POSIXct if .data is not provided
Patient ID column name, or vector of characters or factors if .data is not provided
AKI Stage 1: \(\ge\)0.3 mg/dl (\(\ge\)26.5 mmol/l) increase
AKI Stage 2: N/A
AKI Stage 3: \(\ge\)4.0 mg/dl (\(\ge\)353.6 mmol/l)
See https://kdigo.org/guidelines/acute-kidney-injury/ for more details.
aki_SCr(aki_pt_data, SCr = "SCr_", dttm = "dttm_", pt_id = "pt_id_") aki_pt_data %>% dplyr::mutate(aki = aki_SCr(SCr = SCr_, dttm = dttm_, pt_id = pt_id_))
Run the code above in your browser using DataLab