powered by
Using KDIGO Clinical Practice Guideline for Acute Kidney Injury Volume 2 | Issue 1 | March 2012
aki_bCr(...)# S3 method for data.frame aki_bCr(.data, SCr, bCr, ...)# S3 method for units aki_bCr(SCr, bCr, ...)# S3 method for numeric aki_bCr(SCr, bCr, ...)
# S3 method for data.frame aki_bCr(.data, SCr, bCr, ...)
# S3 method for units aki_bCr(SCr, bCr, ...)
# S3 method for numeric aki_bCr(SCr, bCr, ...)
(ordered factor) AKI stages
Further optional arguments
(data.frame) A data.frame, optional
Serum creatinine column name, or vector of units or numeric if .data is not provided
.data
Baseline creatinine column name, or vector of units or numeric if .data is not provided
AKI Stage 1: 1.5-1.9 times baseline
AKI Stage 2: 2.0-2.9 times baseline
AKI Stage 3: 3.0 times baseline
See https://kdigo.org/guidelines/acute-kidney-injury/ for more details.
aki_bCr(aki_pt_data, SCr = "SCr_", bCr = "bCr_") aki_pt_data %>% dplyr::mutate(aki = aki_bCr(SCr = SCr_, bCr = bCr_))
Run the code above in your browser using DataLab