Learn R Programming

epocakir (version 1.0.0)

aki_staging: Codify AKI from Serum Creatinine and/or Urine Output

Description

Using KDIGO Clinical Practice Guideline for Acute Kidney Injury Volume 2 | Issue 1 | March 2012

Usage

aki_staging(...)

# S3 method for data.frame aki_staging( .data, SCr = NULL, bCr = NULL, UO = NULL, dttm = NULL, pt_id = NULL, ... )

# S3 method for units aki_staging(SCr = NULL, bCr = NULL, UO = NULL, dttm = NULL, pt_id = NULL, ...)

# S3 method for numeric aki_staging(SCr = NULL, bCr = NULL, UO = NULL, dttm = NULL, pt_id = NULL, ...)

Value

(ordered factor) AKI stages

Arguments

...

Further optional arguments

.data

(data.frame) A data.frame, optional

SCr

Serum creatinine column name, or vector of units or numeric if .data is not provided

bCr

Baseline creatinine column name, or vector of units or numeric if .data is not provided

UO

Urine output column name, or vector of units or numeric if .data is not provided

dttm

DateTime column name, or vector of POSIXct if .data is not provided

pt_id

Patient ID column name, or vector of characters or factors if .data is not provided

Details

Provided a baseline creatinine, series of Serum Creatinine readings and/or Urine Output, aki_staging() calculates whether or not a patient has AKI. The staging (1, 2, 3) of AKI is returned.

When multiple columns are provided, aki_staging() will automatically calculate whether or not AKI has occurred using each KDIGO definition.

  • aki_bCr(): Staging of AKI based on baseline serum creatinine

  • aki_SCr(): Staging of AKI based on changes in serum creatinine

  • aki_UO(): Staging of AKI based on urine output

The most severe AKI stage is then returned.

See https://kdigo.org/guidelines/acute-kidney-injury/ for more details.

Examples

Run this code
aki_staging(aki_pt_data, SCr = "SCr_", bCr = "bCr_", UO = "UO_", dttm = "dttm_", pt_id = "pt_id_")

aki_pt_data %>%
  dplyr::mutate(aki = aki_staging(SCr = SCr_, bCr = bCr_, UO = UO_, dttm = dttm_, pt_id = pt_id_))

Run the code above in your browser using DataLab