powered by
Using KDIGO 2012 Clinical Practice Guideline for the Evaluation and Management of Chronic Kidney Disease Volume 3 | Issue 1 | January 2013
eGFR_adult_SCysC(...)# S3 method for data.frame eGFR_adult_SCysC(.data, SCysC, Age, male, ...)# S3 method for units eGFR_adult_SCysC(SCysC, Age, male, ...)# S3 method for numeric eGFR_adult_SCysC(SCysC, Age, male, ...)
# S3 method for data.frame eGFR_adult_SCysC(.data, SCysC, Age, male, ...)
# S3 method for units eGFR_adult_SCysC(SCysC, Age, male, ...)
# S3 method for numeric eGFR_adult_SCysC(SCysC, Age, male, ...)
Estimated GFR of the same type provided (numeric or units)
Further optional arguments
(data.frame) A data.frame, optional
Serum Cystatin C column name, or vector of units or numeric if .data is not provided
.data
Age of patient column name, or vector of units or numeric if .data is not provided
Male or not column name, or vector of logical (TRUE/FALSE) if .data is not provided
See https://kdigo.org/guidelines/ckd-evaluation-and-management/ for more details
eGFR_adult_SCysC(eGFR_pt_data, SCysC = "SCysC_", Age = "Age_", male = "male_" ) eGFR_pt_data %>% dplyr::mutate(eGFR = eGFR_adult_SCysC( SCysC = SCysC_, Age = Age_, male = male_ ))
Run the code above in your browser using DataLab