Learn R Programming

epocakir (version 1.0.0)

eGFR_child_SCr_BUN: eGFR Pediatric SCr, Height and BUN

Description

Using KDIGO 2012 Clinical Practice Guideline for the Evaluation and Management of Chronic Kidney Disease Volume 3 | Issue 1 | January 2013

Usage

eGFR_child_SCr_BUN(...)

# S3 method for data.frame eGFR_child_SCr_BUN(.data, SCr, height, BUN, ...)

# S3 method for units eGFR_child_SCr_BUN(SCr, height, BUN, ...)

# S3 method for numeric eGFR_child_SCr_BUN(SCr, height, BUN, ...)

Value

Estimated GFR of the same type provided (numeric or units)

Arguments

...

Further optional arguments

.data

(data.frame) A data.frame, optional

SCr

Serum creatinine column name, or vector of units or numeric if .data is not provided

height

Height of patient column name, or vector of units or numeric if .data is not provided

BUN

Blood urea nitrogen column name, or vector of units or numeric if .data is not provided

Details

See https://kdigo.org/guidelines/ckd-evaluation-and-management/ for more details

Examples

Run this code
eGFR_child_SCr_BUN(eGFR_pt_data,
  SCr = "SCr_", height = "height_", BUN = "BUN_",
)

eGFR_pt_data %>%
  dplyr::mutate(eGFR = eGFR_child_SCr_BUN(
    SCr = SCr_, height = height_, BUN = BUN_,
  ))

Run the code above in your browser using DataLab